==> logger-elasticsearch-0.1.4.tgz: package/index.ts <==
import Logger from './lib/logger';
import { Client, ClientOptions } from '@elastic/elasticsearch';

export class LoggerElasticSearch extends Logger {
    protected _logger: Client;
    protected _index: string;
    protected _env: string;

    constructor({ index, env, options }: { index: string; env: string; options: ClientOptions }) {
        super();
        this._index = index;
        this._env = env;
        this._logger = new Client(options);
    }

    get logger() {
        return this._logger;
    }

    info(data: object) {
        if (this._env === 'production') {
            this._logger.index({
                index: this._index,
                body: this.createBody(data, 'info'),
            });
        }
    }

    debug(data: object) {
        if (this._env === 'production') {
            this._logger.index({
                index: this._index,
                body: this.createBody(data, 'debug'),
            });
        }
    }

    warn(data: object) {
        if (this._env === 'production') {
            this._logger.index({
                index: this._index,
                body: this.createBody(data, 'warn'),
            });
        }
    }

    error(data: object) {
        if (this._env === 'production') {
            this._logger.index({
                index: this._index,
                body: this.createBody(data, 'error'),
            });
        }
    }

    protected createDocument(data: object) {
        return Object.assign(data, { datetime: new Date() });
    }

    protected createBody(data: object, level: string) {
        return {
            level,
            document: this.createDocument(data),
        };
    }
}

export default LoggerElasticSearch;

==> logger-elasticsearch-0.1.5.tgz: package/index.ts <==
import Logger from './lib/logger';
import { Client, ClientOptions } from '@elastic/elasticsearch';

export class LoggerElasticSearch extends Logger {
    protected _logger: Client;
    protected _index: string;
    protected _env: string;

    constructor({ index, env, options }: { index: string; env: string; options: ClientOptions }) {
        super();
        this._index = index;
        this._env = env;
        this._logger = new Client(options);
    }

    get logger() {
        return this._logger;
    }

    info(data: Record<string, unknown>) {
        if (this._env === 'production') {
            this._logger.index({
                index: this._index,
                body: this.createBody(data, 'info'),
            });
        }
    }

    debug(data: Record<string, unknown>) {
        if (this._env === 'production') {
            this._logger.index({
                index: this._index,
                body: this.createBody(data, 'debug'),
            });
        }
    }

    warn(data: Record<string, unknown>) {
        if (this._env === 'production') {
            this._logger.index({
                index: this._index,
                body: this.createBody(data, 'warn'),
            });
        }
    }

    error(data: Record<string, unknown>) {
        if (this._env === 'production') {
            this._logger.index({
                index: this._index,
                body: this.createBody(data, 'error'),
            });
        }
    }

    protected createDocument(data: Record<string, unknown>): Record<string, unknown> {
        return Object.assign(data, { datetime: new Date() });
    }

    protected createBody(data: Record<string, unknown>, level: string): Record<string, unknown> {
        return {
            level,
            document: this.createDocument(data),
        };
    }
}

export default LoggerElasticSearch;
